==> qmpdclient-1.0.6.2.tar.gz: qmpdclient-1.0.6.2/src/reconnect.cpp <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "config.h"
#include "mpd.h"
#include "reconnect.h"
#include <QTimer>

Reconnect::Reconnect(QObject *parent) : QObject(parent), mpd(MPD::instance()), reconnectTimer(0) {
	setObjectName("reconnect");
	connect(mpd, SIGNAL(connected(ServerInfo)), this, SLOT(connected(ServerInfo)));
	connect(mpd, SIGNAL(disconnected(QString)), this, SLOT(disconnected(QString)));
}

Reconnect::~Reconnect() {
	if (reconnectTimer)
		delete reconnectTimer;
}

void Reconnect::connected(ServerInfo si) {
	server = si;
	// We regained connection, delete timer
	if (reconnectTimer)
		delete reconnectTimer;
	reconnectTimer = 0;
}

void Reconnect::disconnected(QString error) {
	if (error.isEmpty() || !Config::instance()->reconnect())
		return;
	// We lost connection involuntarily
	if (reconnectTimer)
		delete reconnectTimer;
	reconnectTimer = new QTimer();
	connect(reconnectTimer, SIGNAL(timeout()), this, SLOT(reconnect()));
	reconnectTimer->start(Config::instance()->reconnectTime() * 1000);
}

void Reconnect::reconnect() {
	mpd->connectToMPD(server);
}

==> qmpdclient-1.0.7.tar.gz: qmpdclient-1.0.7/src/reconnect.cpp <==
/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "config.h"
#include "mpd.h"
#include "reconnect.h"
#include <QTimer>

Reconnect::Reconnect(QObject *parent) : QObject(parent), m_mpd(MPD::instance()), m_reconnectTimer(0) {
	setObjectName("reconnect");
	connect(m_mpd, SIGNAL(connected(ServerInfo)), this, SLOT(connected(ServerInfo)));
	connect(m_mpd, SIGNAL(disconnected(QString)), this, SLOT(disconnected(QString)));
}

Reconnect::~Reconnect() {
	if (m_reconnectTimer)
		delete m_reconnectTimer;
}

void Reconnect::connected(const ServerInfo &si) {
	m_server = si;
	// We regained connection, delete timer
	if (m_reconnectTimer)
		delete m_reconnectTimer;
	m_reconnectTimer = 0;
}

void Reconnect::disconnected(const QString &error) {
	if (error.isEmpty() || !Config::instance()->reconnect())
		return;
	// We lost connection involuntarily
	if (m_reconnectTimer)
		delete m_reconnectTimer;
	m_reconnectTimer = new QTimer();
	connect(m_reconnectTimer, SIGNAL(timeout()), this, SLOT(reconnect()));
	m_reconnectTimer->start(Config::instance()->reconnectTime() * 1000);
}

void Reconnect::reconnect() {
	m_mpd->connectToMPD(m_server);
}
